@@ -3,13 +3,14 @@ Main interface for chime service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.chime import (
+    from mypy_boto3_chime import (
         ChimeClient,
         Client,
         ListAccountsPaginator,
         ListUsersPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -18,9 +19,12 @@ Usage::
 
     list_accounts_paginator: ListAccountsPaginator = client.get_paginator("list_accounts")
     list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
+    ```
 """
-from mypy_boto3_chime.client import ChimeClient as Client, ChimeClient
+from mypy_boto3_chime.client import ChimeClient
 from mypy_boto3_chime.paginator import ListAccountsPaginator, ListUsersPaginator
 
+Client = ChimeClient
+
 
 __all__ = ("ChimeClient", "Client", "ListAccountsPaginator", "ListUsersPaginator")
