@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for chime service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.chime import (
+
+    from mypy_boto3_chime import ChimeClient
+    from mypy_boto3_chime.paginator import (
         ListAccountsPaginator,
         ListUsersPaginator,
     )
@@ -13,11 +17,13 @@ Usage::
 
     list_accounts_paginator: ListAccountsPaginator = client.get_paginator("list_accounts")
     list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_chime.type_defs import (
     ListAccountsResponseTypeDef,
     ListUsersResponseTypeDef,
@@ -35,7 +41,7 @@ __all__ = ("ListAccountsPaginator", "ListUsersPaginator")
 
 class ListAccountsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAccounts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.39/reference/services/chime.html#Chime.Paginator.ListAccounts)
+    [Paginator.ListAccounts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.10/reference/services/chime.html#Chime.Paginator.ListAccounts)
     """
 
     def paginate(
@@ -45,13 +51,13 @@ class ListAccountsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAccountsResponseTypeDef]:
         """
-        [ListAccounts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.39/reference/services/chime.html#Chime.Paginator.ListAccounts.paginate)
+        [ListAccounts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.10/reference/services/chime.html#Chime.Paginator.ListAccounts.paginate)
         """
 
 
 class ListUsersPaginator(Boto3Paginator):
     """
-    [Paginator.ListUsers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.39/reference/services/chime.html#Chime.Paginator.ListUsers)
+    [Paginator.ListUsers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.10/reference/services/chime.html#Chime.Paginator.ListUsers)
     """
 
     def paginate(
@@ -62,5 +68,5 @@ class ListUsersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListUsersResponseTypeDef]:
         """
-        [ListUsers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.39/reference/services/chime.html#Chime.Paginator.ListUsers.paginate)
+        [ListUsers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.10/reference/services/chime.html#Chime.Paginator.ListUsers.paginate)
         """
